@@ -64,7 +64,6 @@ import org.ovirt.api.metamodel.annotations.Type;
  *       "enabled" : "true",
  *       "merge_across_nodes" : "true"
  *     },
- *     "maintenance_reason_required" : "false",
  *     "memory_policy" : {
  *       "over_commit" : {
  *         "percent" : "100"
@@ -83,7 +82,6 @@ import org.ovirt.api.metamodel.annotations.Type;
  *         "id" : "00000000-0000-0000-0000-000000000000"
  *       }
  *     },
- *     "optional_reason" : "false",
  *     "required_rng_sources" : {
  *       "required_rng_source" : [ "random" ]
  *     },
@@ -223,8 +221,27 @@ public interface Cluster extends Identified {
     Boolean tunnelMigration();
     Boolean trustedService();
     Boolean haReservation();
+
+    /**
+     * This property has no longer any relevance and has been deprecated. Its default value is true.
+     *
+     * @author Dana Elfassy <delfassy@redhat.com>
+     * @date 3 January 2019
+     * @status added
+     */
+    @Deprecated
     Boolean optionalReason();
+
+    /**
+     * This property has no longer any relevance and has been deprecated. Its default value is true,
+     *
+     * @author Dana Elfassy <delfassy@redhat.com>
+     * @date 3 January 2019
+     * @status added
+     */
+    @Deprecated
     Boolean maintenanceReasonRequired();
+
     Boolean ballooningEnabled();
     Display display();
     Ksm ksm();
@@ -357,6 +374,33 @@ public interface Cluster extends Identified {
      */
     FirewallType firewallType();
 
+    /**
+     * The memory consumption threshold for logging audit log events.
+     *
+     * For percentage, an audit log event is logged if the used memory is more that the value specified.
+     * For absolute value, an audit log event is logged when the the free memory falls below the value specified in MB.
+     *
+     * @author Nori Ravi <rnori@redhat.com>
+     * @author Tahlia Richardson <trichard@redhat.com>
+     * @date 10 Aug 2018
+     * @since 4.3
+     * @status updated_by_docs
+     */
+    Integer logMaxMemoryUsedThreshold();
+
+    /**
+     * The memory consumption threshold type for logging audit log events.
+     *
+     * You can choose between 'percentage' and 'absolute_value_in_mb'.
+     *
+     * @author Nori Ravi <rnori@redhat.com>
+     * @author Tahlia Richardson <trichard@redhat.com>
+     * @date 10 Aug 2018
+     * @since 4.3
+     * @status updated_by_docs
+     */
+    LogMaxMemoryUsedThresholdType logMaxMemoryUsedThresholdType();
+
     /**
      * Custom features that are enabled for the cluster.
      *
