@@ -17,6 +17,7 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
@@ -64,7 +65,7 @@ public interface FilesService {
      * @date 14 Jul 2017
      * @status updated_by_docs
      */
-    interface List {
+    interface List extends Follow {
         @Out File[] file();
 
         /**
