@@ -121,6 +121,17 @@ public interface HostService extends MeasurableService {
          * @date 17 Oct 17
          * @status updated_by_docs
          */
+
+        /**
+         * When set to 'true', this host will be activated after its approval completes. When set to 'false'
+         * the host will remain in 'maintenance' status after its approval. Absence of this parameter will be
+         * interpreted as 'true', since the desired default behavior is activating the host after approval.
+         * @author Ori Liel <oliel@redhat.com>
+         * @date 10 Dec 2018
+         * @since 4.3
+         * @status added
+         */
+        @In Boolean activate();
         interface UsingRootPassword extends Approve {
             @InputDetail
             default void inputDetail() {
@@ -171,11 +182,18 @@ public interface HostService extends MeasurableService {
      * <action/>
      * ----
      *
+     * IMPORTANT: Since {engine-name} 4.3, it is possible to also specify `commit_on_success` in
+     * the <<services/host/methods/setup_networks, setupnetworks>> request, in which case the new
+     * configuration is automatically saved in the {hypervisor-name} upon completing the setup and
+     * re-establishing connectivity between the {hypervisor-name} and {engine-name}, and without
+     * waiting for a separate <<services/host/methods/commit_net_config, commitnetconfig>> request.
+     *
      * @author Juan Hernandez <juan.hernandez@redhat.com>
      * @author Martin Mucha <mmucha@redhat.com>
      * @author Megan Lewis <melewis@redhat.com>
-     * @date 17 Oct 17
-     * @status updated_by_docs
+     * @author Eitan Raviv <eraviv@redhat.com>
+     * @date 03 Dec 2018
+     * @status added
      */
     interface CommitNetConfig {
         /**
@@ -449,6 +467,17 @@ public interface HostService extends MeasurableService {
             optional(image());
         }
 
+        /**
+         * When set to 'true', this host will be activated after its installation completes. When set to 'false'
+         * the host will remain in 'maintenance' status after its installation. Absence of this parameter will be
+         * interpreted as 'true', since the desired default behavior is activating the host after install.
+         * @author Ori Liel <oliel@redhat.com>
+         * @date 10 Dec 2018
+         * @since 4.3
+         * @status added
+         */
+        @In Boolean activate();
+
         /**
          * Install VDSM and other packages required to get the host ready to be used in the engine providing the root
          * password. This has been deprecated.
@@ -746,6 +775,7 @@ public interface HostService extends MeasurableService {
             optional(host().powerManagement().enabled());
             optional(host().powerManagement().kdumpDetection());
             optional(host().spm().priority());
+            optional(host().vgpuPlacement());
             or(optional(host().cluster().id()), optional(host().cluster().name()));
 //            optional(host().powerManagement()[COLLECTION].propietary!!();
         }
@@ -1079,13 +1109,22 @@ public interface HostService extends MeasurableService {
      * IMPORTANT: To make sure that the network configuration has been saved in the host, and that it will be applied
      * when the host is rebooted, remember to call <<services/host/methods/commit_net_config, commitnetconfig>>.
      *
+     * IMPORTANT: Since {engine-name} 4.3, it is possible to also specify `commit_on_success` in
+     * the <<services/host/methods/setup_networks, setupnetworks>> request, in which case the new
+     * configuration is automatically saved in the {hypervisor-name} upon completing the setup and
+     * re-establishing connectivity between the {hypervisor-name} and {engine-name}, and without
+     * waiting for a separate <<services/host/methods/commit_net_config, commitnetconfig>> request.
+     *
+     *
      * @author Megan Lewis <melewis@redhat.com>
-     * @date 17 Oct 17
-     * @status updated_by_docs
+     * @author Eitan Raviv <eraviv@redhat.com>
+     * @date 03 Dec 2018
+     * @status added
      */
     interface SetupNetworks {
         @InputDetail
         default void inputDetail() {
+            optional(commitOnSuccess());
             optional(checkConnectivity());
             optional(connectivityTimeout());
             or(optional(modifiedNetworkAttachments()[COLLECTION].hostNic().name()), optional(modifiedNetworkAttachments()[COLLECTION].hostNic().id()));
@@ -1123,6 +1162,21 @@ public interface HostService extends MeasurableService {
         @In HostNic[] removedBonds();
         @In NetworkLabel[] modifiedLabels();
         @In NetworkLabel[] removedLabels();
+
+        /**
+         * Specifies whether to automatically save the configuration in the {hypervisor-name} upon completing
+         * the setup and re-establishing connectivity between the {hypervisor-name} and {engine-name},
+         * and without waiting for a separate <<services/host/methods/commit_net_config, commitnetconfig>>
+         * request.
+         * The default value is `false`, which means that the configuration will not be
+         * saved automatically.
+         *
+         * @author Eitan Raviv <eraviv@redhat.com>
+         * @date 03 Dec 2018
+         * @since 4.3
+         * @status added
+         */
+        @In Boolean commitOnSuccess();
         @In Boolean checkConnectivity();
         @In Integer connectivityTimeout();
 
