@@ -183,4 +183,16 @@ public interface Nic extends Device {
      * @status added
      */
     @Link ReportedDevice[] reportedDevices();
+
+    /**
+     * A link to the network filter parameters.
+     *
+     * @author Dominik Holler <dholler@redhat.com>
+     * @author Megan Lewis <melewis@redhat.com>
+     * @date 21 Feb 2017
+     * @status updated_by_docs
+     * @since 4.2
+     */
+    @Link NetworkFilterParameter[] networkFilterParameters();
+
 }
