@@ -59,6 +59,9 @@ public class XmlActionReader {
         while (reader.forward()) {
             String name = reader.getLocalName();
             switch (name) {
+                case "activate":
+                object.activate(reader.readBoolean());
+                break;
                 case "allow_partial_import":
                 object.allowPartialImport(reader.readBoolean());
                 break;
@@ -95,6 +98,9 @@ public class XmlActionReader {
                 case "comment":
                 object.comment(reader.readString());
                 break;
+                case "commit_on_success":
+                object.commitOnSuccess(reader.readBoolean());
+                break;
                 case "connection":
                 object.connection(XmlStorageConnectionReader.readOne(reader));
                 break;
