@@ -104,7 +104,9 @@ public class ClusterServiceImpl extends ServiceImpl implements ClusterService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlClusterReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.cluster(XmlClusterReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -115,7 +117,7 @@ public class ClusterServiceImpl extends ServiceImpl implements ClusterService {
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -124,7 +126,7 @@ public class ClusterServiceImpl extends ServiceImpl implements ClusterService {
     private class GetResponseImpl implements GetResponse {
         private Cluster cluster;
         
-        public GetResponseImpl(Cluster cluster) {
+        public void cluster(Cluster cluster) {
             this.cluster = cluster;
         }
         
@@ -235,6 +237,50 @@ public class ClusterServiceImpl extends ServiceImpl implements ClusterService {
         return new ResetEmulatedMachineRequestImpl();
     }
     
+    private class SyncAllNetworksRequestImpl extends BaseRequest<SyncAllNetworksRequest, SyncAllNetworksResponse> implements SyncAllNetworksRequest {
+        private Boolean async;
+        public SyncAllNetworksRequest async(Boolean async) {
+            this.async = async;
+            return this;
+        }
+        
+        public SyncAllNetworksResponse send() {
+            HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/syncallnetworks");
+            try (
+              ByteArrayOutputStream output = new ByteArrayOutputStream();
+              XmlWriter xmlWriter = new XmlWriter(output, true)
+            ) {
+                ActionBuilder action = new ActionBuilder();
+                action.async(async);
+                XmlActionWriter.writeOne(action.build(), xmlWriter);
+                xmlWriter.flush();
+                request.setEntity(new ByteArrayEntity(output.toByteArray()));
+            }
+            catch (IOException ex) {
+                throw new Error("Failed to write request", ex);
+            }
+            
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
+            HttpResponse response = getConnection().send(request);
+            Action action = checkAction(response);
+            EntityUtils.consumeQuietly(response.getEntity());
+            return new SyncAllNetworksResponseImpl();
+        }
+        
+    }
+    
+    private class SyncAllNetworksResponseImpl implements SyncAllNetworksResponse {
+    }
+    
+    public SyncAllNetworksRequest syncAllNetworks() {
+        return new SyncAllNetworksRequestImpl();
+    }
+    
     private class UpdateRequestImpl extends BaseRequest<UpdateRequest, UpdateResponse> implements UpdateRequest {
         private Boolean async;
         public UpdateRequest async(Boolean async) {
@@ -295,7 +341,9 @@ public class ClusterServiceImpl extends ServiceImpl implements ClusterService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new UpdateResponseImpl(XmlClusterReader.readOne(reader));
+                    UpdateResponseImpl actionResponse = new UpdateResponseImpl();
+                    actionResponse.cluster(XmlClusterReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -306,7 +354,7 @@ public class ClusterServiceImpl extends ServiceImpl implements ClusterService {
             }
             else {
                 checkFault(response);
-                return new UpdateResponseImpl(null);
+                return new UpdateResponseImpl();
             }
         }
         
@@ -315,7 +363,7 @@ public class ClusterServiceImpl extends ServiceImpl implements ClusterService {
     private class UpdateResponseImpl implements UpdateResponse {
         private Cluster cluster;
         
-        public UpdateResponseImpl(Cluster cluster) {
+        public void cluster(Cluster cluster) {
             this.cluster = cluster;
         }
         
