@@ -18,6 +18,7 @@ package org.ovirt.engine.sdk4.internal.services;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.net.URISyntaxException;
+import java.util.Map;
 import org.apache.http.HttpResponse;
 import org.apache.http.client.methods.HttpDelete;
 import org.apache.http.client.methods.HttpGet;
@@ -27,6 +28,7 @@ import org.apache.http.entity.ByteArrayEntity;
 import org.apache.http.util.EntityUtils;
 import org.ovirt.api.metamodel.runtime.xml.XmlReader;
 import org.ovirt.api.metamodel.runtime.xml.XmlWriter;
+import org.ovirt.engine.sdk4.BaseRequest;
 import org.ovirt.engine.sdk4.Error;
 import org.ovirt.engine.sdk4.Service;
 import org.ovirt.engine.sdk4.builders.DataCenterBuilder;
@@ -36,9 +38,9 @@ import org.ovirt.engine.sdk4.internal.xml.XmlDataCenterWriter;
 import org.ovirt.engine.sdk4.services.AssignedPermissionsService;
 import org.ovirt.engine.sdk4.services.AttachedStorageDomainsService;
 import org.ovirt.engine.sdk4.services.ClustersService;
+import org.ovirt.engine.sdk4.services.DataCenterNetworksService;
 import org.ovirt.engine.sdk4.services.DataCenterService;
 import org.ovirt.engine.sdk4.services.IscsiBondsService;
-import org.ovirt.engine.sdk4.services.NetworksService;
 import org.ovirt.engine.sdk4.services.QossService;
 import org.ovirt.engine.sdk4.services.QuotasService;
 import org.ovirt.engine.sdk4.types.DataCenter;
@@ -49,13 +51,19 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
         super(connection, path);
     }
     
-    private class GetRequestImpl implements GetRequest {
+    private class GetRequestImpl extends BaseRequest<GetRequest, GetResponse> implements GetRequest {
         private Boolean filter;
         public GetRequest filter(Boolean filter) {
             this.filter = filter;
             return this;
         }
         
+        private String follow;
+        public GetRequest follow(String follow) {
+            this.follow = follow;
+            return this;
+        }
+        
         public GetResponse send() {
             HttpGet request = null;
             try {
@@ -63,12 +71,26 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
                 if (filter != null) {
                     uriBuilder.addParameter("filter", XmlWriter.renderBoolean(filter));
                 }
+                if (follow != null) {
+                    uriBuilder.addParameter("follow", XmlWriter.renderString(follow));
+                }
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
                 request = new HttpGet(uriBuilder.build());
             }
             catch (URISyntaxException ex) {
                 throw new Error("Failed to build URL", ex);
             }
             
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
             HttpResponse response = getConnection().send(request);
             if (
               response.getStatusLine().getStatusCode() == 200
@@ -76,7 +98,9 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlDataCenterReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.dataCenter(XmlDataCenterReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -87,7 +111,7 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -96,7 +120,7 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
     private class GetResponseImpl implements GetResponse {
         private DataCenter dataCenter;
         
-        public GetResponseImpl(DataCenter dataCenter) {
+        public void dataCenter(DataCenter dataCenter) {
             this.dataCenter = dataCenter;
         }
         
@@ -110,7 +134,7 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
         return new GetRequestImpl();
     }
     
-    private class RemoveRequestImpl implements RemoveRequest {
+    private class RemoveRequestImpl extends BaseRequest<RemoveRequest, RemoveResponse> implements RemoveRequest {
         private Boolean async;
         public RemoveRequest async(Boolean async) {
             this.async = async;
@@ -133,12 +157,23 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
                 if (force != null) {
                     uriBuilder.addParameter("force", XmlWriter.renderBoolean(force));
                 }
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
                 request = new HttpDelete(uriBuilder.build());
             }
             catch (URISyntaxException ex) {
                 throw new Error("Failed to build URL", ex);
             }
             
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
             HttpResponse response = getConnection().send(request);
             if (
               response.getStatusLine().getStatusCode() == 200
@@ -161,7 +196,7 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
         return new RemoveRequestImpl();
     }
     
-    private class UpdateRequestImpl implements UpdateRequest {
+    private class UpdateRequestImpl extends BaseRequest<UpdateRequest, UpdateResponse> implements UpdateRequest {
         private Boolean async;
         public UpdateRequest async(Boolean async) {
             this.async = async;
@@ -186,6 +221,11 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
                 if (async != null) {
                     uriBuilder.addParameter("async", XmlWriter.renderBoolean(async));
                 }
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
                 request = new HttpPut(uriBuilder.build());
             }
             catch (URISyntaxException ex) {
@@ -203,6 +243,12 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
                 throw new Error("Failed to parse response", ex);
             }
             
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
             HttpResponse response = getConnection().send(request);
             if (
               response.getStatusLine().getStatusCode() == 200
@@ -210,7 +256,9 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new UpdateResponseImpl(XmlDataCenterReader.readOne(reader));
+                    UpdateResponseImpl actionResponse = new UpdateResponseImpl();
+                    actionResponse.dataCenter(XmlDataCenterReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -221,7 +269,7 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
             }
             else {
                 checkFault(response);
-                return new UpdateResponseImpl(null);
+                return new UpdateResponseImpl();
             }
         }
         
@@ -230,7 +278,7 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
     private class UpdateResponseImpl implements UpdateResponse {
         private DataCenter dataCenter;
         
-        public UpdateResponseImpl(DataCenter dataCenter) {
+        public void dataCenter(DataCenter dataCenter) {
             this.dataCenter = dataCenter;
         }
         
@@ -252,8 +300,8 @@ public class DataCenterServiceImpl extends ServiceImpl implements DataCenterServ
         return new IscsiBondsServiceImpl(getConnection(), getPath() + "/iscsibonds");
     }
     
-    public NetworksService networksService() {
-        return new NetworksServiceImpl(getConnection(), getPath() + "/networks");
+    public DataCenterNetworksService networksService() {
+        return new DataCenterNetworksServiceImpl(getConnection(), getPath() + "/networks");
     }
     
     public AssignedPermissionsService permissionsService() {
