@@ -88,7 +88,9 @@ public class GlusterVolumeServiceImpl extends MeasurableServiceImpl implements G
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlGlusterVolumeReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.volume(XmlGlusterVolumeReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -99,7 +101,7 @@ public class GlusterVolumeServiceImpl extends MeasurableServiceImpl implements G
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -108,7 +110,7 @@ public class GlusterVolumeServiceImpl extends MeasurableServiceImpl implements G
     private class GetResponseImpl implements GetResponse {
         private GlusterVolume volume;
         
-        public GetResponseImpl(GlusterVolume volume) {
+        public void volume(GlusterVolume volume) {
             this.volume = volume;
         }
         
@@ -147,7 +149,9 @@ public class GlusterVolumeServiceImpl extends MeasurableServiceImpl implements G
             HttpResponse response = getConnection().send(request);
             Action action = checkAction(response);
             EntityUtils.consumeQuietly(response.getEntity());
-            return new GetProfileStatisticsResponseImpl(action.details());
+            GetProfileStatisticsResponseImpl actionResponse = new GetProfileStatisticsResponseImpl();
+            actionResponse.details(action.details());
+            return actionResponse;
         }
         
     }
@@ -155,7 +159,7 @@ public class GlusterVolumeServiceImpl extends MeasurableServiceImpl implements G
     private class GetProfileStatisticsResponseImpl implements GetProfileStatisticsResponse {
         private GlusterVolumeProfileDetails details;
         
-        public GetProfileStatisticsResponseImpl(GlusterVolumeProfileDetails details) {
+        public void details(GlusterVolumeProfileDetails details) {
             this.details = details;
         }
         
