@@ -76,7 +76,9 @@ public class HostDeviceServiceImpl extends ServiceImpl implements HostDeviceServ
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlHostDeviceReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.device(XmlHostDeviceReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -87,7 +89,7 @@ public class HostDeviceServiceImpl extends ServiceImpl implements HostDeviceServ
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -96,7 +98,7 @@ public class HostDeviceServiceImpl extends ServiceImpl implements HostDeviceServ
     private class GetResponseImpl implements GetResponse {
         private HostDevice device;
         
-        public GetResponseImpl(HostDevice device) {
+        public void device(HostDevice device) {
             this.device = device;
         }
         
