@@ -99,7 +99,9 @@ public class InstanceTypeNicsServiceImpl extends ServiceImpl implements Instance
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddResponseImpl(XmlNicReader.readOne(reader));
+                    AddResponseImpl actionResponse = new AddResponseImpl();
+                    actionResponse.nic(XmlNicReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -110,7 +112,7 @@ public class InstanceTypeNicsServiceImpl extends ServiceImpl implements Instance
             }
             else {
                 checkFault(response);
-                return new AddResponseImpl(null);
+                return new AddResponseImpl();
             }
         }
         
@@ -119,7 +121,7 @@ public class InstanceTypeNicsServiceImpl extends ServiceImpl implements Instance
     private class AddResponseImpl implements AddResponse {
         private Nic nic;
         
-        public AddResponseImpl(Nic nic) {
+        public void nic(Nic nic) {
             this.nic = nic;
         }
         
@@ -199,7 +201,9 @@ public class InstanceTypeNicsServiceImpl extends ServiceImpl implements Instance
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlNicReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.nics(XmlNicReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -210,7 +214,7 @@ public class InstanceTypeNicsServiceImpl extends ServiceImpl implements Instance
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -219,7 +223,7 @@ public class InstanceTypeNicsServiceImpl extends ServiceImpl implements Instance
     private class ListResponseImpl implements ListResponse {
         private List<Nic> nics;
         
-        public ListResponseImpl(List<Nic> nics) {
+        public void nics(List<Nic> nics) {
             this.nics = nics;
         }
         
