@@ -104,6 +104,11 @@ public interface SystemService extends Service {
      * `special_objects` and `summary`.
      */
     public interface GetRequest extends Request<GetRequest, GetResponse> {
+        /**
+         * Indicates which inner links should be _followed_. The objects referenced by these links will be fetched as part
+         * of the current request. See <<documents/003_common_concepts/follow, here>> for details.
+         */
+        GetRequest follow(String follow);
     }
     
     /**
@@ -334,6 +339,10 @@ public interface SystemService extends Service {
     OpenstackNetworkProvidersService openstackNetworkProvidersService();
     OpenstackVolumeProvidersService openstackVolumeProvidersService();
     OperatingSystemsService operatingSystemsService();
+    /**
+     * Reference to the service that provides values of configuration options of the system.
+     */
+    SystemOptionsService optionsService();
     SystemPermissionsService permissionsService();
     RolesService rolesService();
     SchedulingPoliciesService schedulingPoliciesService();
