@@ -15,29 +15,48 @@ limitations under the License.
 
 package org.ovirt.engine.sdk4.types;
 
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+/**
+ * Describes all switch types supported by the Manager.
+ */
 public enum SwitchType {
+    /**
+     * The native switch type.
+     */
+    LEGACY("legacy"),
+    /**
+     * The Open vSwitch type.
+     */
+    OVS("ovs"),
+    ;
     
-    LEGACY,
-    OVS;
+    private static final Logger log = LoggerFactory.getLogger(SwitchType.class);
     
-    private static final Logger LOG = LoggerFactory.getLogger(SwitchType.class);
+    private String image;
+    
+    SwitchType(String image) {
+        this.image = image;
+    }
     
     public String value() {
-        return name().toLowerCase();
+        return image;
     }
     
     public static SwitchType fromValue(String value) {
         try {
             return valueOf(value.toUpperCase());
         }
-        catch (IllegalArgumentException e) {
-            LOG.error("The string '" + value + "' isn't a valid value for the 'SwitchType' enumerated type. Valid values are: 'legacy', 'ovs'.");
+        catch (IllegalArgumentException exception) {
+            log.error(
+            "The string '" + value + "' isn't a valid value for the 'SwitchType' enumerated type. " +
+            "Valid values are 'legacy' and 'ovs'.",
+            exception
+            );
             return null;
         }
     }
     
 }
+
